@@ -6,7 +6,7 @@ use warnings;
 
 use Path::Tiny qw(path);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub exe {
 	my $self = shift;
@@ -59,17 +59,23 @@ Not yet.
 
  use Alien::bc::GNU;
 
- print 'bin_dir: '.Alien::bc::GNU->bin_dir."\n";
+ print 'bin_dir: '.Alien::bc::GNU->bin_dir."\n"
+	if defined Alien::bc::GNU->bin_dir;
  print 'dist_dir: '.Alien::bc::GNU->dist_dir."\n";
  print 'install_type: '.Alien::bc::GNU->install_type."\n";
  print 'version: '.Alien::bc::GNU->version."\n";
 
- # Output like:
+ # Output like (share):
  # bin_dir: ~home/perl5/lib/perl5/x86_64-linux-gnu-thread-multi/auto/share/dist/Alien-bc-GNU/bin
  # dist_dir: ~home/perl5/lib/perl5/x86_64-linux-gnu-thread-multi/auto/share/dist/Alien-bc-GNU
  # install_type: share
  # version: 1.07.1
 
+ # Output like (system):
+ # dist_dir: ~home/perl5/lib/perl5/x86_64-linux-gnu-thread-multi/auto/share/dist/Alien-bc-GNU
+ # install_type: system
+ # version: 1.07.1
+
 =head1 DEPENDENCIES
 
 L<Alien::Base>.
@@ -92,6 +98,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
